@@ -1,6 +1,6 @@
 package SPVM::HTTP::Tiny;
 
-our $VERSION = "0.015";
+our $VERSION = "0.016";
 
 1;
 
@@ -17,8 +17,10 @@ B<This class is highly experimental. Many dramatic incompatibilities are expecte
 =head1 Usage
 
   use HTTP::Tiny;
+  use Go::Context;
   
-  my $response = HTTP::Tiny->new->get('http://example.com/');
+  my $ctx = Go::Context->background;
+  my $response = HTTP::Tiny->new->get($ctx, 'http://example.com/');
   
   unless ($response->success) {
     die "Failed!";
@@ -52,11 +54,11 @@ C<has agent : ro string;>
 
 The user agent.
 
-=head2 timeout
+=head2 inactivity_timeout
 
-C<has timeout : ro double;>
+C<has inactivity_timeout : ro double;>
 
-The request timeout seconds.
+The request inactivity_timeout seconds.
 
 =head1 Class Methods
 
@@ -74,9 +76,9 @@ Options:
 
 Sets the L</"agent"> field.
 
-=item C<timeout> : Double
+=item C<inactivity_timeout> : Double
 
-Sets the L</"timeout"> field.
+Sets the L</"inactivity_timeout"> field.
 
 =back
 
@@ -84,7 +86,7 @@ Sets the L</"timeout"> field.
 
 =head2 get
 
-C<method get : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method get : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 Gets the HTTP response by sending an HTTP GET request to the URL $url.
 
@@ -98,7 +100,7 @@ Options:
 
 Headers for an HTTP request.
 
-=item C<timeout> : Double
+=item C<inactivity_timeout> : Double
 
 Timeout seconds.
 
@@ -106,23 +108,23 @@ Timeout seconds.
 
 =head2 head
 
-C<method head : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method head : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 =head2 put
 
-C<method put : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method put : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 =head2 post
 
-C<method post : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method post : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 =head2 patch
 
-C<method patch : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method patch : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 =head2 delete
 
-C<method delete : HTTP::Tiny::Response ($url : string, $options : object[] = undef);>
+C<method delete : HTTP::Tiny::Response ($ctx : L<Go::Context|SPVM::Go::Context>, $url : string, $options : object[] = undef);>
 
 =head1 Repository
 
@@ -137,4 +139,3 @@ Yuki Kimoto C<kimoto.yuki@gmail.com>
 Copyright (c) 2023 Yuki Kimoto
 
 MIT License
-
